==> LAPOINTE.db_2.2.0.tar.gz: LAPOINTE.db/man/LAPOINTE_dbconn.Rd <==
\name{LAPOINTE_dbconn}

\alias{LAPOINTE_dbconn}
\alias{LAPOINTE_dbfile}
\alias{LAPOINTE_dbschema}
\alias{LAPOINTE_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  LAPOINTE_dbconn()
  LAPOINTE_dbfile()
  LAPOINTE_dbschema(file="", show.indices=FALSE)
  LAPOINTE_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{LAPOINTE_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{LAPOINTE_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{LAPOINTE_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{LAPOINTE_dbschema} prints the schema definition of the
  package annotation DB.

  \code{LAPOINTE_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{LAPOINTE_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{LAPOINTE_dbfile}: a character string with the path to the
  package annotation DB.

  \code{LAPOINTE_dbschema}: none (invisible \code{NULL}).

  \code{LAPOINTE_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(LAPOINTE_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by LAPOINTE_dbconn() was created with:
  dbConnect(SQLite(), dbname=LAPOINTE_dbfile(), cache_size=64000, synchronous=0)

  LAPOINTE_dbschema()

  LAPOINTE_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> LAPOINTE.db_2.6.3.tar.gz: LAPOINTE.db/man/LAPOINTE_dbconn.Rd <==

\name{LAPOINTE_dbconn}

\alias{LAPOINTE_dbconn}
\alias{LAPOINTE_dbfile}
\alias{LAPOINTE_dbschema}
\alias{LAPOINTE_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  LAPOINTE_dbconn()
  LAPOINTE_dbfile()
  LAPOINTE_dbschema(file="", show.indices=FALSE)
  LAPOINTE_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{LAPOINTE_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{LAPOINTE_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{LAPOINTE_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{LAPOINTE_dbschema} prints the schema definition of the
  package annotation DB.

  \code{LAPOINTE_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{LAPOINTE_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{LAPOINTE_dbfile}: a character string with the path to the
  package annotation DB.

  \code{LAPOINTE_dbschema}: none (invisible \code{NULL}).

  \code{LAPOINTE_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(LAPOINTE_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by LAPOINTE_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=LAPOINTE_dbfile(), cache_size=64000,
  synchronous=0)

  LAPOINTE_dbschema()

  LAPOINTE_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
